==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/CLAUSEFORQUOTATIONREQUESTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CLAUSEFORQUOTATIONREQUESTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CLAUSEFORQUOTATIONREQUESTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUOTATIONREQUESTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLAUSEID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CLAUSEFORQUOTATIONREQUESTID_Type", propOrder = {
    "quotationrequestid",
    "clauseid"
})
public class CLAUSEFORQUOTATIONREQUESTID_Type {

    @XmlElement(name = "QUOTATIONREQUESTID", required = true)
    protected QUOTATIONREQUESTID_Type quotationrequestid;
    @XmlElement(name = "CLAUSEID", required = true)
    protected CLAUSEID_Type clauseid;

    /**
     * Obtient la valeur de la propriété quotationrequestid.
     * 
     * @return
     *     possible object is
     *     {@link QUOTATIONREQUESTID_Type }
     *     
     */
    public QUOTATIONREQUESTID_Type getQUOTATIONREQUESTID() {
        return quotationrequestid;
    }

    /**
     * Définit la valeur de la propriété quotationrequestid.
     * 
     * @param value
     *     allowed object is
     *     {@link QUOTATIONREQUESTID_Type }
     *     
     */
    public void setQUOTATIONREQUESTID(QUOTATIONREQUESTID_Type value) {
        this.quotationrequestid = value;
    }

    /**
     * Obtient la valeur de la propriété clauseid.
     * 
     * @return
     *     possible object is
     *     {@link CLAUSEID_Type }
     *     
     */
    public CLAUSEID_Type getCLAUSEID() {
        return clauseid;
    }

    /**
     * Définit la valeur de la propriété clauseid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLAUSEID_Type }
     *     
     */
    public void setCLAUSEID(CLAUSEID_Type value) {
        this.clauseid = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/CLAUSEFORQUOTATIONREQUESTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CLAUSEFORQUOTATIONREQUESTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CLAUSEFORQUOTATIONREQUESTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUOTATIONREQUESTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLAUSEID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CLAUSEFORQUOTATIONREQUESTID_Type", propOrder = {
    "quotationrequestid",
    "clauseid"
})
public class CLAUSEFORQUOTATIONREQUESTID_Type {

    @XmlElement(name = "QUOTATIONREQUESTID", required = true)
    protected QUOTATIONREQUESTID_Type quotationrequestid;
    @XmlElement(name = "CLAUSEID", required = true)
    protected CLAUSEID_Type clauseid;

    /**
     * Gets the value of the quotationrequestid property.
     * 
     * @return
     *     possible object is
     *     {@link QUOTATIONREQUESTID_Type }
     *     
     */
    public QUOTATIONREQUESTID_Type getQUOTATIONREQUESTID() {
        return quotationrequestid;
    }

    /**
     * Sets the value of the quotationrequestid property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUOTATIONREQUESTID_Type }
     *     
     */
    public void setQUOTATIONREQUESTID(QUOTATIONREQUESTID_Type value) {
        this.quotationrequestid = value;
    }

    /**
     * Gets the value of the clauseid property.
     * 
     * @return
     *     possible object is
     *     {@link CLAUSEID_Type }
     *     
     */
    public CLAUSEID_Type getCLAUSEID() {
        return clauseid;
    }

    /**
     * Sets the value of the clauseid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLAUSEID_Type }
     *     
     */
    public void setCLAUSEID(CLAUSEID_Type value) {
        this.clauseid = value;
    }

}
